/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Debug.h"
#include "ConflictDialog.h"
#include "XmlOptions.h"

#include <QLabel>

//______________________________________________________________________
ConflictDialog::ConflictDialog( QWidget* parent ):
    FileSelectionDialog( parent, "Following files exists both locally and remotely.\n"
    "Decide which action is to be taken for transfer. " )
{

    Debug::Throw( "ConflictDialog::ConflictDialog.\n" );

    // setOptionName( "CONFLICT_DIALOG" );

    // skip
    _workLayout().addWidget( skipButton_ = new QPushButton( tr( "Skip" ), &_mainWidget() ) );
    skipButton_->setToolTip( tr( "Skip selected files from transfer" ) );
    connect( skipButton_, SIGNAL(clicked()), SLOT(_skip()) );

    // overwrite
    _workLayout().addWidget( overwriteButton_ = new QPushButton( tr( "Overwrite" ), &_mainWidget() ) );
    overwriteButton_->setToolTip( tr( "Overwrite selected files" ) );
    connect( overwriteButton_, SIGNAL(clicked()), SLOT(_overwrite()) );

    // adjust list mask
    _list().setMask( _list().mask()|(1<<FileInfoModel::Action) );

}

//____________________________________________________________________
void ConflictDialog::_updateButtons()
{
    Debug::Throw( "ConflictDialog::_updateButtons.\n" );
    FileSelectionDialog::_updateButtons();

    bool has_selection( !_list().selectionModel()->selectedRows().empty() );
    skipButton_->setEnabled( has_selection );
    overwriteButton_->setEnabled( has_selection );
}

//____________________________________________________________________
void ConflictDialog::_skip()
{

    Debug::Throw( "ConflictDialog::_skip.\n" );

    // retrieve selected items, change action
    FileInfo::List selection( selectedFiles() );
    for( auto& fileInfo:selection )
    { fileInfo.setStatus( FileInfo::Overwrite, false ); }

    // update model
    _model().add( selection );

    _list().resizeColumnToContents( FileInfoModel::Action );

}

//____________________________________________________________________
void ConflictDialog::_overwrite()
{

    Debug::Throw( "ConflictDialog::_overwrite.\n" );

    // retrieve selected items, change action
    FileInfo::List selection( selectedFiles() );
    for( auto& fileInfo:selection )
    { fileInfo.setStatus( FileInfo::Overwrite, true ); }

    // update model
    _model().add( selection );
    _list().resizeColumnToContents( FileInfoModel::Action );

}
