/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ConnectionAttributes.h"

#include "Debug.h"
#include "FileInfo.h"
#include "XmlDef.h"
#include "XmlOptions.h"

//_______________________________________________________________________
ConnectionAttributes::ConnectionAttributes():
    Counter( "ConnectionAttributes" )
{ Debug::Throw( "ConnectionAttributes::ConnectionAttributes (empty).\n" ); }

//_______________________________________________________________________
ConnectionAttributes::ConnectionAttributes( const QDomElement& element ):
    Counter( "ConnectionAttributes" )
{

    Debug::Throw( "ConnectionAttributes::ConnectionAttributes.\n" );
    bool savePasswords = XmlOptions::get().get<bool>("SAVE_PASSWORDS");

    // parse attributes
    QDomNamedNodeMap attributes( element.attributes() );
    for( int i=0; i<attributes.count(); i++ )
    {

        QDomAttr attribute( attributes.item( i ).toAttr() );
        if( attribute.isNull() ) continue;
        QString name( attribute.name() );
        QString value( attribute.value() );

        if( name == Xml::Name ) setName( value );
        else if( name == Xml::Host ) setHost( value );
        else if( name == Xml::Port ) setPort( value.toInt() );
        else if( name == Xml::User ) setUser( value );
        else if( name == Xml::Password ) { if( savePasswords ) setPassword( value ); }
        else if( name == Xml::Default ) setIsDefault( value.toInt() );
        else Debug::Throw(0) << "ConnectionAttributes::ConnectionAttributes - unrecognized name " << name << endl;

    }

    Debug::Throw( "ConnectionAttributes::ConnectionAttributes - done.\n" );

}

//___________________________________________
QDomElement ConnectionAttributes::domElement( QDomDocument& parent ) const
{
    Debug::Throw( "ConnectionAttributes::DomElement.\n");
    QDomElement out( parent.createElement( Xml::Connection ) );

    // attributes
    bool savePasswords = XmlOptions::get().get<bool>("SAVE_PASSWORDS");
    out.setAttribute( Xml::Name, name() );
    out.setAttribute( Xml::Host, host() );
    out.setAttribute( Xml::Port, QString::number( port() ) );
    out.setAttribute( Xml::User, user() );
    if( savePasswords ) out.setAttribute( Xml::Password, password() );
    out.setAttribute( Xml::Default, QString::number( isDefault() ) );
    return out;

}
