#ifndef ConnectionDialog_h
#define ConnectionDialog_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseDialog.h"
#include "ConnectionAttributes.h"
#include "ConnectionModel.h"
#include "ConnectionParser.h"
#include "Counter.h"
#include "ListModel.h"

#include <QPushButton>
#include <QCloseEvent>

class ConnectionFrame;
class SimpleListView;

//* handles list of connection attributes
class ConnectionDialog: public BaseDialog, private Base::Counter<ConnectionDialog>
{

    //* Qt meta object declaration
    Q_OBJECT

    public:

    //* constructor
    explicit ConnectionDialog( QWidget* );

    //* connection frame
    ConnectionFrame& frame() const
    { return *frame_; }

    protected:

    //* close
    void closeEvent( QCloseEvent* ) override;

    //* load connections from parser
    void _load();

    protected Q_SLOTS:

    //* save settings
    void _select();

    //* save settings
    void _save();

    //* remove settings
    void _remove();

    //* connect
    void _connect();

    //* toggle save password
    void _toggleSavePasswords( bool );

    //* show/hide password
    void _toggleShowPassword( bool );

    //* cancel
    void _cancel();

    //* update buttons
    void _updateButtons();

    private:

    //* model
    ConnectionModel model_;

    //* list
    SimpleListView* list_;

    //* connection parser
    ConnectionParser parser_;

    //* connection frame
    ConnectionFrame* frame_;

    //*@name buttons
    //@{

    //* save
    QPushButton* saveButton_;

    //* remove
    QPushButton* removeButton_;

    //* connect
    QPushButton* connectButton_;

    //@}

};

#endif
