#ifndef ConnectionModel_h
#define ConnectionModel_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ListModel.h"
#include "ConnectionAttributes.h"

#include <QIcon>

#include <array>

//* connection model
class ConnectionModel: public ListModel<ConnectionAttributes>, private Base::Counter<ConnectionModel>
{

    Q_OBJECT

    public:

    //* column types
    enum ColumnTypes
    {
        Name,
        Host,
        Port,
        User,
        nColumns
    };

    //* constructor
    explicit ConnectionModel( QObject* = nullptr );

    //* data
    QVariant data(const QModelIndex&, int) const override;

    //* header data
    QVariant headerData(int, Qt::Orientation, int = Qt::DisplayRole) const override;

    //* number of columns for a given index
    int columnCount(const QModelIndex& = QModelIndex()) const override
    { return nColumns; }

    private:

    //* list column names
    const std::array<QString, nColumns> columnTitles_ =
    {{
        tr( "Name" ),
        tr( "Host" ),
        tr( "Port" ),
        tr( "User" )
    }};

    //* icon
    QIcon icon_;

};

#endif
