#ifndef FileSelectionClipboard_h
#define FileSelectionClipboard_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "FileInfo.h"

//* clipboard
class FileSelectionClipboard
{

    public:

    // clipboard mode
    enum Mode
    {
        Cut,
        Copy
    };

    //* constructor
    explicit FileSelectionClipboard( const FileInfo::List& files = FileInfo::List(), Mode mode = Copy ):
        files_( files ),
        mode_( mode )
    { Debug::Throw( "FileSelectionClipboard::FileSelectionClipboard" ); }

    //*@name accessors
    //@{

    //* files
    const FileInfo::List& get() const
    { return files_; }

    //* true if empty
    bool isEmpty() { return files_.isEmpty(); }

    //* description
    QString description( int flags = 0 ) const
    { return FileInfo::Description( flags ).get( files_ ); }

    //* clipboard mode
    Mode mode() const
    { return mode_; }

    //@}

    //*@name modifiers
    //@{

    //* files
    void setFiles( const FileInfo::List& files )
    { files_ = files; }

    //* clipboard mode
    void setMode( Mode value )
    { mode_ = value; }

    //* clear
    void clear() { files_.clear(); }

    //* remove local files
    inline void removeLocal( bool isLocal );

    //@}

    private:

    //* files
    FileInfo::List files_;

    //* clipboard mode
    Mode mode_ = Copy;

};

//* equal to operator
inline bool operator == (const FileSelectionClipboard& first, const FileSelectionClipboard& second)
{ return first.get() == second.get() && first.mode() == second.mode(); }

//________________________________________________________________
void FileSelectionClipboard::removeLocal( bool isLocal )
{

    auto iter( files_.begin() );
    while( iter != files_.end() )
    {
        if( iter->isLocal() != isLocal ) iter = files_.erase( iter );
        else ++iter;
    }

}

#endif
