/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "FtpCommandModel.h"

#include "IconNames.h"
#include "IconEngine.h"
#include "Singleton.h"
#include "TimeStamp.h"
#include "XmlOptions.h"

#include <QIcon>

//_______________________________________________
FtpCommandModel::IconCache& FtpCommandModel::_icons()
{
    static IconCache cache;
    return cache;
}

//_______________________________________________________________
FtpCommandModel::FtpCommandModel( QObject* parent ):
    ListModel<FtpCommand>( parent ),
    Counter( "FtpCommandModel" )
{

    Debug::Throw( "FtpCommandModel::FtpCommandModel.\n" );
    connect( Base::Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
    _updateConfiguration();

}

//__________________________________________________________________
QVariant FtpCommandModel::data( const QModelIndex& index, int role ) const
{

    // check index
    if( !contains( index ) ) return QVariant();

    // retrieve associated command
    const FtpCommand& command( get()[index.row()] );

    // return text associated to command and column
    if( role == Qt::DisplayRole )
    {

        switch( index.column() )
        {
            case Name: return command.name();
            case Filename: return command.argumentCount() > 0  ? command.argument(0).file().get():QVariant();

            default:
            return QVariant();
        }

    } else if( role == Qt::DecorationRole && index.column() == Name ) {

        // return icon associated to file
        return _icons()[command.type()];

    }

    return QVariant();

}

//__________________________________________________________________
QVariant FtpCommandModel::headerData(int section, Qt::Orientation orientation, int role) const
{

    if(
        orientation == Qt::Horizontal &&
        role == Qt::DisplayRole &&
        section >= 0 &&
        section < nColumns )
    { return columnTitles_[section]; }

    // return empty
    return QVariant();

}

//_________________________________________________________
void FtpCommandModel::_updateConfiguration()
{

    Debug::Throw( "FtpCommandModel::_updateConfiguration.\n" );

    beginResetModel();

    // reinitialize icons
    _icons().clear();
    _installIcons();

    endResetModel();

}

//_____________________________________________________________________
void FtpCommandModel::_installIcons() const
{

    Debug::Throw( "FtpCommandModel::_installIcons" );

    if( _icons().empty() )
    {

        _icons() = Base::makeT<IconCache>( {
            { FtpCommand::Type::CreateDirectory, IconEngine::get( IconNames::CreateDirectory ) },
            { FtpCommand::Type::ChangeDirectory, IconEngine::get( IconNames::Open ) },
            { FtpCommand::Type::ShowDirectory, IconEngine::get( IconNames::Find ) },
            { FtpCommand::Type::Remove, IconEngine::get( IconNames::Delete ) },
            { FtpCommand::Type::Copy, IconEngine::get( IconNames::Paste ) },
            { FtpCommand::Type::Login, IconEngine::get( IconNames::Connect ) },
            { FtpCommand::Type::ConnectToHost, IconEngine::get( IconNames::Connect ) },
            { FtpCommand::Type::Close, IconEngine::get( IconNames::Disconnect ) },
            { FtpCommand::Type::Rename, IconEngine::get( IconNames::Rename ) }
        });
    }

    return;
}
