#ifndef FtpDefines_h
#define FtpDefines_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "File.h"

#include <QString>
#include <QRegExp>

class Ftp
{
    public:

    static const QString localPrefix;
    static const QString remotePrefix;

    static QRegExp localPrefixRegExp;
    static QRegExp remotePrefixRegExp;

    //* true if file is remote
    static bool isRemote( const File& file )
    { return file.get().indexOf( remotePrefixRegExp ) == 0; }

    //* true if file is local
    static bool isLocal( const File& file )
    { return !isRemote( file ); }

    //* truncated file name
    static File baseName( const File& file )
    {
        if( file.get().indexOf( localPrefixRegExp ) == 0 ) return File( file.get().mid( localPrefixRegExp.matchedLength() ) );
        else if( file.get().indexOf( remotePrefixRegExp ) == 0 ) return File( file.get().mid( remotePrefixRegExp.matchedLength() ) );
        else return file;
    }

};

#endif
