/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "FtpMacro.h"
#include "CppUtil.h"

//___________________________________________________________________
const FtpMacro::NameMap& FtpMacro::_names()
{
    static const FtpMacro::NameMap names = Base::makeT<NameMap>(
    {
        { FtpMacro::Type::None, QObject::tr( "none" ) },
        { FtpMacro::Type::Connect, QObject::tr( "connect to host" ) },
        { FtpMacro::Type::CloseConnection, QObject::tr( "close connection" ) },
        { FtpMacro::Type::Add, QObject::tr( "add file to internal list" ) },
        { FtpMacro::Type::Clear, QObject::tr( "clear internal file list" ) },
        { FtpMacro::Type::Abort, QObject::tr( "abort transfer" ) },
        { FtpMacro::Type::CopyRecursive, QObject::tr( "copy selected items" ) },
        { FtpMacro::Type::CreateDirectory, QObject::tr( "create directory" ) },
        { FtpMacro::Type::Rename, QObject::tr( "rename selected item" ) },
        { FtpMacro::Type::Remove, QObject::tr( "remove selected items" ) },
        { FtpMacro::Type::Open, QObject::tr( "open files" ) },
        { FtpMacro::Type::ShowDirectory, QObject::tr( "query directory content" ) },
        { FtpMacro::Type::ListRecursive, QObject::tr( "query directory content (recursive)" ) },
        { FtpMacro::Type::SizeRecursive, QObject::tr( "query directory size (recursive)" ) },
        { FtpMacro::Type::CheckConflicts, QObject::tr( "check file conflicts" ) },
        { FtpMacro::Type::CheckFilesCopy, QObject::tr( "check file transfer (copy)" ) },
        { FtpMacro::Type::CheckFilesMoved, QObject::tr( "check file transfer (move)" ) },
        { FtpMacro::Type::CheckFilesExist, QObject::tr( "check file existence" ) },
        { FtpMacro::Type::ClearSelection, QObject::tr( "clear display selection" ) },
        { FtpMacro::Type::Select, QObject::tr( "update display selection" ) }
    });

    return names;
}

//___________________________________________________________________
int& FtpMacro::_counter()
{
    static int counter( 0 );
    return counter;
}

//_________________________________________
FtpMacro::FtpMacro( Type type, FileInfo::List&& arguments ):
    Counter( "FtpMacro" ),
    id_( _counter()++ ),
    type_( type ),
    arguments_( std::move( arguments ) )
{}
