/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "FtpMacroModel.h"

#include "CustomPixmap.h"
#include "IconNames.h"
#include "IconEngine.h"
#include "IconSize.h"
#include "TimeStamp.h"
#include "XmlOptions.h"

#include <QIcon>

//_______________________________________________________________
FtpMacroModel::FtpMacroModel( QObject* parent ):
    ListModel<FtpMacro>( parent ),
    Counter( "FtpMacroModel" )
{

    Debug::Throw( "FtpMacroModel::FtpMacroModel.\n" );
    updateConfiguration();

}

//__________________________________________________________________
QVariant FtpMacroModel::data( const QModelIndex& index, int role ) const
{

    // check index
    if( !contains( index ) ) return QVariant();

    // retrieve associated macro
    const FtpMacro& macro( get()[index.row()] );

    // return text associated to macro and column
    if( role == Qt::DisplayRole ) {

        switch( index.column() )
        {

            case Name: return macro.name();
            case Filename: return macro.argumentCount() > 0  ? macro.argument(0).file().get():QVariant();
            default: return QVariant();
        }
    } else if( role == Qt::DecorationRole && index.column() == Name ) {

        // return icon associated to file
        return _icon(macro.type());

    }

    return QVariant();

}

//__________________________________________________________________
QVariant FtpMacroModel::headerData(int section, Qt::Orientation orientation, int role) const
{

    if(
        orientation == Qt::Horizontal &&
        role == Qt::DisplayRole &&
        section >= 0 &&
        section < nColumns )
    { return columnTitles_[section]; }

    // return empty
    return QVariant();

}

//_________________________________________________________
void FtpMacroModel::updateConfiguration()
{

    Debug::Throw( "FtpMacroModel::updateConfiguration.\n" );

    beginResetModel();

    // reinitialize icons
    _icons().clear();
    _installIcons();

    endResetModel();

}

//_____________________________________________________________________
void FtpMacroModel::_installIcons() const
{

    Debug::Throw( "FtpMacroList::_installIcons" );

    if( _icons().empty() )
    {
        _icons() = Base::makeT<IconCache>( {
            { FtpMacro::Type::Connect, IconEngine::get( IconNames::Connect ) },
            { FtpMacro::Type::Add, IconEngine::get( IconNames::Add ) },
            { FtpMacro::Type::Clear, IconEngine::get( IconNames::Delete ) },
            { FtpMacro::Type::Abort, IconEngine::get( IconNames::Abort ) },
            { FtpMacro::Type::CopyRecursive, IconEngine::get( IconNames::Paste ) },
            { FtpMacro::Type::CreateDirectory, IconEngine::get( IconNames::CreateDirectory ) },
            { FtpMacro::Type::Rename, IconEngine::get( IconNames::Rename ) },
            { FtpMacro::Type::Remove, IconEngine::get( IconNames::Delete ) },
            { FtpMacro::Type::Open, IconEngine::get( IconNames::Edit ) },
            { FtpMacro::Type::ShowDirectory, IconEngine::get( IconNames::Find ) },
            { FtpMacro::Type::ListRecursive, IconEngine::get( IconNames::Find ) }
        });

    }
    return;
}

//_______________________________________________
FtpMacroModel::IconCache& FtpMacroModel::_icons()
{
    static IconCache cache;
    return cache;
}

//____________________________________________________________
const QIcon& FtpMacroModel::_icon( FtpMacro::Type type )
{

    IconCache::iterator iter = ( _icons().find( type ) );
    if( iter != _icons().end() ) return iter.value();
    else return _icons().insert( type, CustomPixmap( IconSize::get( IconSize::Medium ), CustomPixmap::Flag::Transparent ) ).value();

}
