#ifndef FtpMacroModel_h
#define FtpMacroModel_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "ListModel.h"
#include "FtpMacro.h"

#include <QHash>

#include <array>

//* Job model. Stores job information for display in lists
class FtpMacroModel : public ListModel<FtpMacro>, private Base::Counter<FtpMacroModel>
{

    //* Qt meta object declaration
    Q_OBJECT

    public:

    //* constructor
    explicit FtpMacroModel(QObject* = nullptr);

    //* column type enumeration
    enum ColumnType
    {
        Name,
        Filename,
        nColumns
    };

    //*@name methods reimplemented from base class
    //@{

    //* data
    QVariant data(const QModelIndex &index, int role) const override;

    //* header data
    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;

    //* number of columns for a given index
    int columnCount(const QModelIndex & = QModelIndex()) const override
    { return nColumns; }

    //@}

    public Q_SLOTS:

    //* add macro
    void add( const FtpMacro& macro )
    { ListModel<FtpMacro>::add( macro ); }

    //* add macros
    void add( const FtpMacro::List& macros )
    { ListModel<FtpMacro>::add( macros ); }

    //* remove
    void remove( const FtpMacro& macro )
    { ListModel<FtpMacro>::remove( macro ); }

    //* update configuration
    void updateConfiguration();

    private:

    //* install pixmaps
    void _installIcons() const;

    //* icon from macro type
    static const QIcon& _icon( FtpMacro::Type );

    //* icon cache
    using IconCache = QHash<FtpMacro::Type, QIcon>;

    static IconCache& _icons();

    //* list column names
    const std::array<QString, nColumns> columnTitles_ =
    {{
        tr( "Name" ),
        tr( "File" )
    }};


};

#endif
